==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Vorige pagina");
define("_NEXT","Volgende pagina");
define("_YOURNAME","Uw naam");
define("_SORTASC","Sorteer oplopend");
define("_SORTDESC","Sorteer aflopend");
define("_CANCEL","Afbreken");
define("_YES","Ja");
define("_NO","Nee");
define("_SCORE","Score:");
define("_REPLYMAIN","Opmerking plaatsen");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_POSTANON","Anoniem plaatsen");
define("_WRITEREVIEW","Schrijf een recensie");
define("_WRITEREVIEWFOR","Schrijf een recensie voor");
define("_ENTERINFO","Informatie invoeren volgens de specificaties a.u.b.");
define("_PRODUCTTITLE","Product titel");
define("_NAMEPRODUCT","Naam van het gerecenseerde product");
define("_REVIEW","Recensie");
define("_CHECKREVIEW","Uw eigen recensie van minimaal 100 woorden. Let op spelfouten. U mag ook (correcte) HTML-tags gebruiken.");
define("_FULLNAMEREQ","Uw volledige naam. Verplicht.");
define("_REMAIL","Uw Email");
define("_REMAILREQ","Uw E-mailadres. Verplicht.");
define("_SELECTSCORE","Score voor dit product");
define("_RELATEDLINK","Verwante link");
define("_PRODUCTSITE","Product website. Zorg ervoor dat de URL met \"http://\" begint");
define("_LINKTITLE","Linktitel");
define("_LINKTITLEREQ","Alleen verplicht als U een verwante link hebt ingevuld.");
define("_RIMAGEFILE","Bestandsnaam figuur");
define("_RIMAGEFILEREQ","Naam van de coverimage, staat in images/reviews/. Niet verplicht.");
define("_CHECKINFO","Voer alleen correcte informatie in, in een juiste opmaak en gebruik niet allemaal HOOFDLETTERS. Berichten die niet aan deze eisen voldoen, worden NIET geplaatst.");
define("_INVALIDTITLE","Er moet een titel worden ingevuld.");
define("_INVALIDSCORE","De score moet tussen 1 en 10 liggen.");
define("_INVALIDTEXT","De recensietekst moet worden ingevuld.");
define("_INVALIDHITS","Het aantal hits moet een positief geheel getal zijn.");
define("_CHECKNAME","U moet zowel uw naam als uw e-mailadres ingeven.");
define("_INVALIDEMAIL","Ongeldig emailadres.");
define("_INVALIDLINK","U moet een linktitel EN een verwante link opgeven, of allebei niet invullen");
define("_ADDED","Toegevoegd:");
define("_REVIEWER","Recensent:");
define("_REVIEWID","Recensie ID:");
define("_HITS","Hits:");
define("_LOOKSRIGHT","Alles naar wens ingevuld?");
define("_RMODIFIED","Gewijzigd:");
define("_RADDED","Toegevoegd");
define("_ADMINLOGGED","Momenteel ingelogd als Admin... deze recensie wordt meteen");
define("_RTHANKS","Bedankt voor deze recensie");
define("_MODIFICATION","Wijziging:");
define("_ISAVAILABLE","De recensie is nu toegevoed aan de recensiedatabase.");
define("_EDITORWILLLOOK","Uw inzending zal worden bekeken. Uw inzending zal binnenkort beschikbaar zijn.");
define("_RBACK","Terug naar recensieindex");
define("_RWELCOME","Welkom op het recensiegedeelte");
define("_10MOSTPOP","10 populairste recensies");
define("_10MOSTREC","10 nieuwste recensies");
define("_THEREARE","Er zijn");
define("_REVIEWSINDB","recensies in de Database");
define("_REVIEWS","Recensies");
define("_REVIEWSLETTER","Recensies voor brief");
define("_NOREVIEWS","Er is geen recensie voor brief");
define("_TOTALREVIEWS","Totaal aantal recensies gevonden.");
define("_RETURN2MAIN","Terug naar hoofdmenu");
define("_REVIEWCOMMENT","Opmerkingen over de recensie:");
define("_YOURNICK","Uw inlognaam:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Creer</a> een account");
define("_YOURCOMMENT","Uw opmerkingen:");
define("_MYSCORE","Mijn score:");
define("_REVIEWMOD","Recensie wijziging:");
define("_RDATE","Datum:");
define("_RTITLE","Titel:");
define("_RTEXT","Tekst:");
define("_REVEMAIL","E-mail:");
define("_RLINK","Link:");
define("_RLINKTITLE","Linktitel:");
define("_COVERIMAGE","Coverimage:");
define("_PREMODS","Bekijk wijzigingen");
define("_PAGE","Pagina");
define("_PAGEBREAK","Als u meerdere pagina's wilt, voer dan <b>&lt;!--pagebreak--&gt;</b> in voor elke nieuwe pagina.");
define("_PREVIEW","Preview");
define("_LANGUAGE","Taal");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Vorige pagina");
define("_NEXT","Volgende pagina");
define("_YOURNAME","Uw naam");
define("_SORTASC","Sorteer oplopend");
define("_SORTDESC","Sorteer aflopend");
define("_CANCEL","Afbreken");
define("_YES","Ja");
define("_NO","Nee");
define("_SCORE","Score:");
define("_REPLYMAIN","Opmerking plaatsen");
define("_ALLOWEDHTML","Toegestane HTML:");
define("_POSTANON","Anoniem plaatsen");
define("_WRITEREVIEW","Schrijf een recensie");
define("_WRITEREVIEWFOR","Schrijf een recensie voor");
define("_ENTERINFO","Informatie invoeren volgens de specificaties a.u.b.");
define("_PRODUCTTITLE","Product titel");
define("_NAMEPRODUCT","Naam van het gerecenseerde product");
define("_REVIEW","Recensie");
define("_CHECKREVIEW","Uw eigen recensie van minimaal 100 woorden. Let op spelfouten. U mag ook (correcte) HTML-tags gebruiken.");
define("_FULLNAMEREQ","Uw volledige naam. Verplicht.");
define("_REMAIL","Uw Email");
define("_REMAILREQ","Uw E-mailadres. Verplicht.");
define("_SELECTSCORE","Score voor dit product");
define("_RELATEDLINK","Verwante link");
define("_PRODUCTSITE","Product website. Zorg ervoor dat de URL met \"http://\" begint");
define("_LINKTITLE","Linktitel");
define("_LINKTITLEREQ","Alleen verplicht als U een verwante link hebt ingevuld.");
define("_RIMAGEFILE","Bestandsnaam figuur");
define("_RIMAGEFILEREQ","Naam van de coverimage, staat in images/reviews/. Niet verplicht.");
define("_CHECKINFO","Voer alleen correcte informatie in, in een juiste opmaak en gebruik niet allemaal HOOFDLETTERS. Berichten die niet aan deze eisen voldoen, worden NIET geplaatst.");
define("_INVALIDTITLE","Er moet een titel worden ingevuld.");
define("_INVALIDSCORE","De score moet tussen 1 en 10 liggen.");
define("_INVALIDTEXT","De recensietekst moet worden ingevuld.");
define("_INVALIDHITS","Het aantal hits moet een positief geheel getal zijn.");
define("_CHECKNAME","U moet zowel uw naam als uw e-mailadres ingeven.");
define("_INVALIDEMAIL","Ongeldig emailadres.");
define("_INVALIDLINK","U moet een linktitel EN een verwante link opgeven, of allebei niet invullen");
define("_ADDED","Toegevoegd:");
define("_REVIEWER","Recensent:");
define("_REVIEWID","Recensie ID:");
define("_HITS","Hits:");
define("_LOOKSRIGHT","Alles naar wens ingevuld?");
define("_RMODIFIED","Gewijzigd:");
define("_RADDED","Toegevoegd");
define("_ADMINLOGGED","Momenteel ingelogd als Admin... deze recensie wordt meteen");
define("_RTHANKS","Bedankt voor deze recensie");
define("_MODIFICATION","Wijziging:");
define("_ISAVAILABLE","De recensie is nu toegevoed aan de recensiedatabase.");
define("_EDITORWILLLOOK","Uw inzending zal worden bekeken. Uw inzending zal binnenkort beschikbaar zijn.");
define("_RBACK","Terug naar recensieindex");
define("_RWELCOME","Welkom op het recensiegedeelte");
define("_10MOSTPOP","10 populairste recensies");
define("_10MOSTREC","10 nieuwste recensies");
define("_THEREARE","Er zijn");
define("_REVIEWSINDB","recensies in de Database");
define("_REVIEWS","Recensies");
define("_REVIEWSLETTER","Recensies voor brief");
define("_NOREVIEWS","Er is geen recensie voor brief");
define("_TOTALREVIEWS","Totaal aantal recensies gevonden.");
define("_RETURN2MAIN","Terug naar hoofdmenu");
define("_REVIEWCOMMENT","Opmerkingen over de recensie:");
define("_YOURNICK","Uw inlognaam:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Creer</a> een account");
define("_YOURCOMMENT","Uw opmerkingen:");
define("_MYSCORE","Mijn score:");
define("_REVIEWMOD","Recensie wijziging:");
define("_RDATE","Datum:");
define("_RTITLE","Titel:");
define("_RTEXT","Tekst:");
define("_REVEMAIL","E-mail:");
define("_RLINK","Link:");
define("_RLINKTITLE","Linktitel:");
define("_COVERIMAGE","Coverimage:");
define("_PREMODS","Bekijk wijzigingen");
define("_PAGE","Pagina");
define("_PAGEBREAK","Als u meerdere pagina's wilt, voer dan <b>&lt;!--pagebreak--&gt;</b> in voor elke nieuwe pagina.");
define("_PREVIEW","Preview");
define("_LANGUAGE","Taal");

?>
